@@ -1,17 +1,14 @@
-import sys
-
 from ploomber.cli.parsers import CustomParser
 from ploomber.cli.io import cli_endpoint
 from ploomber.telemetry import telemetry
-import datetime
 
 # TODO: we are just smoke testing this, we need to improve the tests
 # (check the appropriate functions are called)
 
 
 @cli_endpoint
+@telemetry.log_call('task')
 def main():
-    start_time = datetime.datetime.now()
     parser = CustomParser(description='Build tasks', prog='ploomber task')
     with parser:
         parser.add_argument('task_name')
@@ -56,9 +53,3 @@ def main():
 
     if no_flags or args.build:
         task.build(force=args.force)
-
-    end_time = datetime.datetime.now()
-    telemetry.log_api("ploomber_task",
-                      total_runtime=str(end_time - start_time),
-                      dag=dag,
-                      metadata={'argv': sys.argv})
