@@ -5,6 +5,7 @@ import io
 import tokenize
 from difflib import Differ
 import parso
+import ast
 
 try:
     import sqlparse
@@ -15,6 +16,7 @@ try:
     import autopep8
 except ImportError:
     autopep8 = None
+from ploomber.products.serializeparams import remove_non_serializable_top_keys
 
 
 def normalize_null(code):
@@ -44,27 +46,35 @@ def normalize_python(code):
     if code is None:
         return None
 
-    code = _delete_python_comments(code)
-
-    if not autopep8 or not parso:
-        raise ImportError('autopep8 and parso are required for normalizing '
-                          'Python code: pip install autopep8 parso')
-
-    node = parso.parse(code).children[0]
-
-    if node.type == 'decorated':
-        node = node.children[-1]
-
     try:
-        doc_node = node.get_doc_node()
-    except Exception:
-        # function without docstring...
-        doc_node = None
+        ast.parse(code)
 
-    if doc_node is not None:
-        code = code.replace('\n' + doc_node.get_code(), '')
+    except SyntaxError:
+        pass
 
-    code = autopep8.fix_code(code)
+    else:
+        code = _delete_python_comments(code)
+
+        if not autopep8 or not parso:
+            raise ImportError(
+                'autopep8 and parso are required for normalizing '
+                'Python code: pip install autopep8 parso')
+
+        node = parso.parse(code).children[0]
+
+        if node.type == 'decorated':
+            node = node.children[-1]
+
+        try:
+            doc_node = node.get_doc_node()
+        except Exception:
+            # function without docstring...
+            doc_node = None
+
+        if doc_node is not None:
+            code = code.replace('\n' + doc_node.get_code(), '')
+
+        code = autopep8.fix_code(code)
 
     return code
 
@@ -102,7 +112,9 @@ class CodeDiffer:
     }
 
     def is_different(self, a, b, a_params, b_params, extension=None):
-        """Compares code and params to determine if it's changed
+        """
+        Compares code and params to determine if it's changed. Ignores top-keys
+        in a_params or b_params if they're no JSON serializable.
 
         Parameters
         ----------
@@ -145,7 +157,9 @@ class CodeDiffer:
         if a_params is None or b_params is None:
             outdated_params = False
         else:
-            outdated_params = (a_params != b_params)
+            a_params_ = remove_non_serializable_top_keys(a_params)
+            b_params_ = remove_non_serializable_top_keys(b_params)
+            outdated_params = (a_params_ != b_params_)
 
         result = outdated_params or (a_norm != b_norm)
         # TODO: improve diff view, also show a params diff view. probably
